/***********************************************************************
 *                copyright 2004, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
/* getpixmap - read a bitmap file to use for pixmap display */
/* written 30apr91 by Phil Fincannon                    */
/* based on example from O'Reilly Volume 4M             */

#include <stdio.h>
#include <Xm/Xm.h>
#include <X11/Intrinsic.h>	/* Intrinsics Definitions */
#include <X11/StringDefs.h>	/* Standard Name-String definitions */
/*
#include <X11/Xaw/Label.h>   */ /* Athena Label Widget */

Pixmap *
getbitmap (toplevel, fn)
   Widget toplevel;
   char *fn;
{
   Arg arg;
   Pixmap  *bitmap;
   unsigned int width,height;
   int x_hot,y_hot;

	if (XReadBitmapFile(XtDisplay(toplevel),XtWindow(toplevel),
		fn,&width,&height,bitmap,&x_hot,&y_hot) != 0)
	    fprintf(stderr, "getbitmap: could not find bitmap: %s\n",fn);
	return bitmap;
}
